Crate android_context

Crate android_context 

WIP successor to ndk-context

Structs

AndroidContext
AndroidContext provides the pointers required to interface with the jni on Android platforms.

Functions

activities
All registered Android activities. Most apps should not use this, instead use either android_app_context() which is global for the entire application or receive an explicit Context handle for the Activity that is relevant (i.e. via raw-window-handle).
add_activity
android_app_context
Returns the application context as acquired from getApplicationContext() on the first
remove_activity