WIP successor to ndk-context
Structs
- Android
Context AndroidContextprovides the pointers required to interface with the jni on Android platforms.
Functions
- activities
- All registered Android activities. Most apps should not use this, instead use either
android_app_context()which is global for the entire application or receive an explicitContexthandle for theActivitythat is relevant (i.e. viaraw-window-handle). - add_
activity - android_
app_ context - Returns the application context as acquired from
getApplicationContext()on the first - remove_
activity