pub fn activities() -> Vec<AndroidContext>Expand description
All registered Android activities. Most apps should not use this, instead use either
android_app_context() which is global for the entire application or receive an explicit
Context handle for the Activity that is relevant (i.e. via raw-window-handle).